@@ -24,6 +24,7 @@
 #include <QIODevice>
 #include <QPrinter>
 #include <QPixmap>
+#include <QDateTime>
 #include <QUrl>
 
 #include "PlatformBackends/ImageGrabber.h"
@@ -52,31 +53,28 @@ class ExportManager : public QObject
 
     public:
 
-    Q_PROPERTY(QString saveLocation READ saveLocation WRITE setSaveLocation NOTIFY saveLocationChanged)
     Q_PROPERTY(QPixmap pixmap READ pixmap WRITE setPixmap NOTIFY pixmapChanged)
     Q_PROPERTY(QString windowTitle READ windowTitle WRITE setWindowTitle)
     Q_PROPERTY(ImageGrabber::GrabMode grabMode READ grabMode WRITE setGrabMode)
 
-    void setSaveLocation(const QString &location);
-    QString saveLocation() const;
-    QUrl lastSavePath() const;
+    QString defaultSaveLocation() const;
     bool isFileExists(const QUrl &url) const;
     void setPixmap(const QPixmap &pixmap);
     QPixmap pixmap() const;
+    void updatePixmapTimestamp();
     void setWindowTitle(const QString &windowTitle);
     QString windowTitle() const;
     ImageGrabber::GrabMode grabMode() const;
     void setGrabMode(const ImageGrabber::GrabMode &grabMode);
 
-    signals:
+    Q_SIGNALS:
 
     void errorMessage(const QString &str);
-    void saveLocationChanged(const QString &location);
     void pixmapChanged(const QPixmap &pixmap);
     void imageSaved(const QUrl &savedAt);
     void forceNotify(const QUrl &savedAt);
 
-    public slots:
+    public Q_SLOTS:
 
     QUrl getAutosaveFilename();
     QUrl tempSave(const QString &mimetype = QStringLiteral("png"));
@@ -101,7 +99,7 @@ class ExportManager : public QObject
     bool isTempFileAlreadyUsed(const QUrl &url) const;
 
     QPixmap mSavePixmap;
-    QUrl mLastSavePath;
+    QDateTime mPixmapTimestamp;
     QUrl mTempFile;
     QTemporaryDir *mTempDir;
     QList<QUrl> mUsedTempFileNames;
