@@ -32,20 +32,19 @@ class GeneralOptionsPage : public SettingsPage
 
     explicit GeneralOptionsPage(QWidget *parent = nullptr);
 
-    public slots:
+    public Q_SLOTS:
 
     void saveChanges() Q_DECL_OVERRIDE;
     void resetChanges() Q_DECL_OVERRIDE;
 
-    private slots:
+    private Q_SLOTS:
 
-    void markDirty(bool checked);
+    void markDirty();
 
     private:
 
     QCheckBox *mRememberRect;
     QCheckBox *mUseLightBackground;
-    QCheckBox *mCopyPathToClipboard;
     QCheckBox *mShowMagnifier;
 };
 
