@@ -26,39 +26,39 @@
 
 #include <QLineEdit>
 #include <QLabel>
+#include <QFormLayout>
 #include <QGroupBox>
-#include <QVBoxLayout>
+#include <QHBoxLayout>
 #include <QComboBox>
 #include <QImageWriter>
+#include <QCheckBox>
 
 SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
     SettingsPage(parent)
 {
-    // set up the layout. start with the directory
-
-    QGroupBox *dirGroup = new QGroupBox(i18n("Default Save Location"), this);
-    QVBoxLayout *dirLayout = new QVBoxLayout;
-    dirGroup->setLayout(dirLayout);
-
-    QHBoxLayout *urlRequesterLayout = new QHBoxLayout;
-    urlRequesterLayout->addWidget(new QLabel(i18n("Location:"), this));
+    QFormLayout *mainLayout = new QFormLayout;
+    setLayout(mainLayout);
 
+    // Save location
     mUrlRequester = new KUrlRequester;
     mUrlRequester->setMode(KFile::Directory);
     connect(mUrlRequester, &KUrlRequester::textChanged, this, &SaveOptionsPage::markDirty);
-    urlRequesterLayout->addWidget(mUrlRequester);
+    mainLayout->addRow(i18n("Save Location:"), mUrlRequester);
 
-    dirLayout->addLayout(urlRequesterLayout);
+    // copy file location to clipboard after saving
+    mCopyPathToClipboard = new QCheckBox(i18n("Copy file location to clipboard after saving"), this);
+    connect(mCopyPathToClipboard, &QCheckBox::toggled, this, &SaveOptionsPage::markDirty);
+    mainLayout->addRow(QString(), mCopyPathToClipboard);
+
+
+    mainLayout->addItem(new QSpacerItem(0, 18, QSizePolicy::Fixed, QSizePolicy::Fixed));
+
+
+    // filename chooser and instructional text
+    QVBoxLayout *saveNameLayout = new QVBoxLayout;
 
     // filename chooser text field
-
-    QGroupBox *fmtGroup = new QGroupBox(i18n("Default Save Filename"));
-    QVBoxLayout *fmtLayout = new QVBoxLayout;
-    fmtGroup->setLayout(fmtLayout);
-
-    QHBoxLayout *saveNameLayout = new QHBoxLayout;
-    saveNameLayout->addWidget(new QLabel(i18n("Filename:"), this));
-
+    QHBoxLayout *saveFieldLayout = new QHBoxLayout;
     mSaveNameFormat = new QLineEdit;
     connect(mSaveNameFormat, &QLineEdit::textEdited, this, &SaveOptionsPage::markDirty);
     connect(mSaveNameFormat, &QLineEdit::textEdited, [&](const QString &newText) {
@@ -73,7 +73,8 @@ SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
             }
         }
     });
-    saveNameLayout->addWidget(mSaveNameFormat);
+    mSaveNameFormat->setPlaceholderText(QStringLiteral("%d"));
+    saveFieldLayout->addWidget(mSaveNameFormat);
 
     mSaveImageFormat = new QComboBox;
     mSaveImageFormat->addItems([&](){
@@ -84,13 +85,11 @@ SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
         return items;
     }());
     connect(mSaveImageFormat, &QComboBox::currentTextChanged, this, &SaveOptionsPage::markDirty);
-    saveNameLayout->addWidget(mSaveImageFormat);
-
-    fmtLayout->addLayout(saveNameLayout);
+    saveFieldLayout->addWidget(mSaveImageFormat);
+    saveNameLayout->addLayout(saveFieldLayout);
 
     // now the save filename format layout
-
-    const QString helpText = i18n(
+    const QString helpText = i18nc("%1 is the default filename of a screenshot",
         "<p>You can use the following placeholders in the filename, which will be replaced "
         "with actual text when the file is saved:</p>"
 
@@ -102,40 +101,32 @@ SaveOptionsPage::SaveOptionsPage(QWidget *parent) :
             "<b>%H</b>: Hour<br />"
             "<b>%m</b>: Minute<br />"
             "<b>%S</b>: Second<br />"
-            "<b>%T</b>: Window title"
+            "<b>%T</b>: Window title<br />"
+            "<b>%d</b>: Sequential numbering<br />"
+            "<b>%Nd</b>: Sequential numbering, padded out to N digits"
         "</blockquote>"
 
-        "<p>To save to a sub-folder, use slashes to describe the desired path, e.g.:</p>"
+        "<p>To save to a sub-folder, use slashes, e.g.:</p>"
 
         "<blockquote>"
-            "<b>%Y</b>/<b>%M</b>/Screenshot_<b>%Y%M%D</b>_<b>%H%m%S</b>"
-        "</blockquote>"
+            "<b>%Y</b>/<b>%M</b>/%1"
+        "</blockquote>",
+        SpectacleConfig::instance()->defaultFilename() + SpectacleConfig::instance()->defaultTimestampTemplate()
     );
 
     QLabel *fmtHelpText = new QLabel(helpText, this);
     fmtHelpText->setWordWrap(true);
     fmtHelpText->setTextFormat(Qt::RichText);
-    fmtHelpText->setSizePolicy(QSizePolicy::MinimumExpanding, QSizePolicy::MinimumExpanding);
-    fmtLayout->addWidget(fmtHelpText);
+    fmtHelpText->setSizePolicy(QSizePolicy::Preferred, QSizePolicy::MinimumExpanding);
+    saveNameLayout->addWidget(fmtHelpText);
+    mainLayout->addRow(i18n("Filename:"), saveNameLayout);
 
     // read in the data
-
     resetChanges();
-
-    // finish up with the main layout
-
-    QVBoxLayout *mainLayout = new QVBoxLayout(this);
-
-    mainLayout->addWidget(dirGroup);
-    mainLayout->addWidget(fmtGroup);
-
-    mainLayout->addStretch(4);
-    setLayout(mainLayout);
 }
 
-void SaveOptionsPage::markDirty(const QString &text)
+void SaveOptionsPage::markDirty()
 {
-    Q_UNUSED(text);
     mChangesMade = true;
 }
 
@@ -147,9 +138,10 @@ void SaveOptionsPage::saveChanges()
 
     // save the data
 
-    cfgManager->setAutoSaveLocation(mUrlRequester->url().toDisplayString(QUrl::PreferLocalFile));
+    cfgManager->setDefaultSaveLocation(mUrlRequester->url().toDisplayString(QUrl::PreferLocalFile));
     cfgManager->setAutoSaveFilenameFormat(mSaveNameFormat->text());
     cfgManager->setSaveImageFormat(mSaveImageFormat->currentText().toLower());
+    cfgManager->setCopySaveLocationToClipboard(mCopyPathToClipboard->checkState() == Qt::Checked);
 
     // done
 
@@ -165,7 +157,8 @@ void SaveOptionsPage::resetChanges()
     // read in the data
 
     mSaveNameFormat->setText(cfgManager->autoSaveFilenameFormat());
-    mUrlRequester->setUrl(QUrl::fromUserInput(cfgManager->autoSaveLocation()));
+    mUrlRequester->setUrl(QUrl::fromUserInput(cfgManager->defaultSaveLocation()));
+    mCopyPathToClipboard->setChecked(cfgManager->copySaveLocationToClipboard());
 
     // read in the save image format and calculate its index
 
