@@ -26,6 +26,7 @@ class QDialogButtonBox;
 class QLineEdit;
 class QComboBox;
 class KUrlRequester;
+class QCheckBox;
 
 class SaveOptionsPage : public SettingsPage
 {
@@ -35,14 +36,14 @@ class SaveOptionsPage : public SettingsPage
 
     explicit SaveOptionsPage(QWidget *parent = nullptr);
 
-    public slots:
+    public Q_SLOTS:
 
     void saveChanges() Q_DECL_OVERRIDE;
     void resetChanges() Q_DECL_OVERRIDE;
 
-    private slots:
+    private Q_SLOTS:
 
-    void markDirty(const QString &text);
+    void markDirty();
 
     private:
 
@@ -50,6 +51,8 @@ class SaveOptionsPage : public SettingsPage
     QLineEdit        *mSaveNameFormat;
     KUrlRequester    *mUrlRequester;
     QComboBox        *mSaveImageFormat;
+    QCheckBox        *mCopyPathToClipboard;
+
 };
 
 #endif // SAVEOPTIONSPAGE_H
