@@ -36,20 +36,55 @@ SpectacleConfig* SpectacleConfig::instance()
     return &instance;
 }
 
+QString SpectacleConfig::defaultFilename() const
+{
+    return QStringLiteral("Screenshot");
+}
+
+QString SpectacleConfig::defaultTimestampTemplate() const
+{
+    // includes separator at the front
+    return QStringLiteral("_%Y%M%D_%H%m%S");
+}
+
 // lastSaveAsLocation
 
+QUrl SpectacleConfig::lastSaveAsFile() const
+{
+    return mGeneralConfig.readEntry(QStringLiteral("lastSaveAsFile"),
+                                    QUrl(this->defaultSaveLocation()));
+}
+
+void SpectacleConfig::setLastSaveAsFile(const QUrl &location)
+{
+    mGeneralConfig.writeEntry(QStringLiteral("lastSaveAsFile"), location);
+    mGeneralConfig.sync();
+}
+
 QUrl SpectacleConfig::lastSaveAsLocation() const
 {
-    return mGeneralConfig.readEntry(QStringLiteral("lastSaveAsLocation"),
-                                    QUrl::fromUserInput(QStandardPaths::writableLocation(QStandardPaths::PicturesLocation) + QStringLiteral("/")));
+    return this->lastSaveAsFile().adjusted(QUrl::RemoveFilename);
 }
 
-void SpectacleConfig::setLastSaveAsLocation(const QUrl &location)
+// lastSaveLocation
+
+QUrl SpectacleConfig::lastSaveFile() const
 {
-    mGeneralConfig.writeEntry(QStringLiteral("lastSaveAsLocation"), location);
+    return mGeneralConfig.readEntry(QStringLiteral("lastSaveFile"),
+                                    QUrl(this->defaultSaveLocation()));
+}
+
+void SpectacleConfig::setLastSaveFile(const QUrl &location)
+{
+    mGeneralConfig.writeEntry(QStringLiteral("lastSaveFile"), location);
     mGeneralConfig.sync();
 }
 
+QUrl SpectacleConfig::lastSaveLocation() const 
+{
+    return this->lastSaveFile().adjusted(QUrl::RemoveFilename);
+}
+
 // cropRegion
 
 QRect SpectacleConfig::cropRegion() const
@@ -216,8 +251,9 @@ void SpectacleConfig::setLastUsedSaveMode(SaveMode mode)
 
 QString SpectacleConfig::autoSaveFilenameFormat() const
 {
-    return mGeneralConfig.readEntry(QStringLiteral("save-filename-format"),
-                          QStringLiteral("Screenshot_%Y%M%D_%H%m%S"));
+    const QString sff = mGeneralConfig.readEntry(QStringLiteral("save-filename-format"),
+                                           QString(defaultFilename() + defaultTimestampTemplate()));
+    return sff.isEmpty() ? QStringLiteral("%d") : sff;
 }
 
 void SpectacleConfig::setAutoSaveFilenameFormat(const QString &format)
@@ -228,13 +264,13 @@ void SpectacleConfig::setAutoSaveFilenameFormat(const QString &format)
 
 // autosave location
 
-QString SpectacleConfig::autoSaveLocation() const
+QString SpectacleConfig::defaultSaveLocation() const
 {
     return mGeneralConfig.readPathEntry(QStringLiteral("default-save-location"),
                           QStandardPaths::writableLocation(QStandardPaths::PicturesLocation));
 }
 
-void SpectacleConfig::setAutoSaveLocation(const QString &location)
+void SpectacleConfig::setDefaultSaveLocation(const QString &location)
 {
     mGeneralConfig.writePathEntry(QStringLiteral("default-save-location"), location);
     mGeneralConfig.sync();
