@@ -18,6 +18,7 @@
  */
 
 #include "SpectacleCore.h"
+#include "spectacle_core_debug.h"
 
 #include "Config.h"
 #include "PlatformBackends/DummyImageGrabber.h"
@@ -93,6 +94,7 @@ SpectacleCore::SpectacleCore(StartMode startMode, ImageGrabber::GrabMode grabMod
 
     switch (startMode) {
     case DBusMode:
+    default:
         break;
     case BackgroundMode: {
             int msec = (KWindowSystem::compositingActive() ? 200 : 50) + delayMsec;
@@ -172,7 +174,7 @@ void SpectacleCore::takeNewScreenshot(const ImageGrabber::GrabMode &mode,
 
 void SpectacleCore::showErrorMessage(const QString &errString)
 {
-    qDebug() << "ERROR: " << errString;
+    qCDebug(SPECTACLE_CORE_LOG) << "ERROR: " << errString;
 
     if (mStartMode == GuiMode) {
         KMessageBox::error(nullptr, errString);
@@ -182,10 +184,12 @@ void SpectacleCore::showErrorMessage(const QString &errString)
 void SpectacleCore::screenshotUpdated(const QPixmap &pixmap)
 {
     mExportManager->setPixmap(pixmap);
+    mExportManager->updatePixmapTimestamp();
 
     switch (mStartMode) {
     case BackgroundMode:
     case DBusMode:
+    default:
         {
             if (mNotify) {
                 connect(mExportManager, &ExportManager::imageSaved, this, &SpectacleCore::doNotify);
@@ -215,6 +219,7 @@ void SpectacleCore::screenshotFailed()
         emit allDone();
         return;
     case DBusMode:
+    default:
         emit grabFailed();
         emit allDone();
         return;
@@ -244,6 +249,7 @@ void SpectacleCore::doNotify(const QUrl &savedAt)
     case ImageGrabber::GrabMode::RectangularRegion:
         notify->setTitle(i18nc("A rectangular region was captured, heading", "Rectangular Region Captured"));
         break;
+    case ImageGrabber::GrabMode::InvalidChoice:
     default:
         break;
     }
